@@ -159,10 +159,13 @@ class FlaviusHeader(FlaviusBase):
                                             create_url=conf.FLAVIUS_API_HEADER_CREATE,
                                             update_url='', delete_url='')
 
-    def search(self, query=dict(slip_type=0)):
+    def search(self, query=None):
         self.search_url += parse.urlencode(query=query, doseq=True)
 
         return super(FlaviusHeader, self).search(query=query)
+    
+    def create(self, query=dist(slip_type=0)):
+        return super(FlaviusHeader, self).create(query=query)
 
 
 class FlaviusData(FlaviusBase):
